using System.Collections.ObjectModel;
using System.ComponentModel;

namespace WpfApplication2
{
    public class MainViewModel
    {
        private readonly ObservableCollection<RowViewModel> rows;

        public MainViewModel()
        {
            rows = new ObservableCollection<RowViewModel>
                       {
                           new RowViewModel {Id = 1, DataWithPresentation = new DataWithPresentation(10, State.Stale)},
                           new RowViewModel {Id = 2, DataWithPresentation = new DataWithPresentation(10, State.Current)},
                           new RowViewModel {Id = 3, DataWithPresentation = new DataWithPresentation(15, State.Current)},
                           new RowViewModel {Id = 4, DataWithPresentation = new DataWithPresentation(25, State.Stale)}
                       };
        }

        public ObservableCollection<RowViewModel> Rows
        {
            get { return rows; }
        }
    }

    public class RowViewModel : INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;

        private int id;
        public int Id
        {
            get { return id; }
            set
            {
                id = value;
                if (PropertyChanged != null)
                    PropertyChanged(this, new PropertyChangedEventArgs("Id"));
            }
        }

        private DataWithPresentation dataWithPresentation;
        public DataWithPresentation DataWithPresentation
        {
            get { return dataWithPresentation; }
            set
            {
                dataWithPresentation = value;
                if(PropertyChanged != null)
                    PropertyChanged(this, new PropertyChangedEventArgs("DataWithPresentation"));
            }
        }
    }

    public class DataWithPresentation
    {
        private int count;
        private readonly State state;

        public DataWithPresentation(int count, State state)
        {
            this.count = count;
            this.state = state;
        }

        public int Count
        {
            get { return count; }
        }

        public State State
        {
            get { return state; }
        }
    }

    public enum State
    {
        Current,
        Stale,
    }
}